export default async function() {
  const { store } = this.context

  if (this.shouldStop || !this.isActive) {
    this.isActive = false
    this.shouldStop = false
    console.debug('engine stopped')
    return
  }

  let delay = 0
  try {
    const response = await this.callApi('/api/sync', {
        v: store.state.engine.version + 1,
        g: store.state.engine.user?.game,
    })

    this.parseSyncData(response.data)
  } catch (e) {
    if (!e.response) {
      // request aborted or other causes
      return
    }

    const { status, statusText } = e.response
    if (status != 200) {
      console.warn(`HTTP ${status} ${statusText}`)
      delay = 5000
      store.commit('engine/setVersion', -1)
    }
  }

  const now = new Date().getTime()
  const last = this.lastFetched.splice(0, 1)
  this.lastFetched.push(now)

  if (now - last < 1000) {
    console.warn('engine: respawning too fast, throttling down')
    delay = 5000
  }
  window.setTimeout(() => {
    this.fetchUpdate()
  }, delay)
}
