package main

import (
	"fmt"
	"os"
	"sirlab.de/go/knowyt/application"
	"sirlab.de/go/knowyt/applicationConfig"
	"sirlab.de/go/knowyt/handler"
)

func main() {
	appConfig := applicationConfig.NewApplicationConfig()
	app, err := application.NewApplication(appConfig)
	if err != nil {
		fmt.Printf("%v\n", err)
		os.Exit(1)
	}
	mux := handler.NewAuthMux(app)

	mux.PublicHandleFunc("/__intern__/exit", handler.Exit)
	mux.PublicHandleFunc("/api/login", mux.Login)
	mux.PublicHandleFunc("/api/logout", mux.Logout)
	mux.PublicHandleFunc("/api/createGame", app.CreateGame)
	mux.PrivateHandleFunc("/api/cameo", mux.Cameo)
	mux.PrivateHandleFunc("/api/userinfo", mux.GetUserInfo)
	mux.PrivateHandleFunc("/api/gameinfo", app.GetGameInfo)
	mux.PrivateHandleFunc("/api/games", app.GetGames)
	mux.PrivateHandleFunc("/api/setGameName", app.SetGameName)
	mux.PrivateHandleFunc("/api/setGameLang", app.SetGameLang)
	mux.PrivateHandleFunc("/api/savePlayer", app.SavePlayer)
	mux.PrivateHandleFunc("/api/deletePlayer", app.DeletePlayer)
	mux.PrivateHandleFunc("/api/sync", app.SyncHandler)
	mux.PrivateHandleFunc("/api/collectQuotes", app.CollectQuotes)
	mux.PrivateHandleFunc("/api/startGame", app.StartGame)
	mux.PrivateHandleFunc("/api/resetGame", app.ResetGame)
	mux.PrivateHandleFunc("/api/continueGame", app.ContinueGame)
	mux.PrivateHandleFunc("/api/finishGame", app.FinishGame)
	mux.PrivateHandleFunc("/api/saveSelection", app.SaveSelection)
	mux.PrivateHandleFunc("/api/getQuotes", app.GetQuotes)
	mux.PrivateHandleFunc("/api/saveQuote", app.SaveQuote)
	mux.PrivateHandleFunc("/api/removeQuote", app.RemoveQuote)

	// default handler
	mux.PublicHandleFunc("/", handler.FileHandler)

	// start listening
	fmt.Printf("http://localhost:%d/\n", mux.Port)
	mux.ListenAndServe()
}
